DOH input fields witout textDir support Tests

# Test DateTextBox Widget with _BidiSupport

Group 1: Date (local format)

dir = ltr, textDir = rtl | dir = ltr, textDir = ltr
--- | ---
dir = rtl, textDir = rtl | dir = rtl, textDir = ltr

Group 2: Date (local format - long)

dir = ltr, textDir = rtl | dir = ltr, textDir = ltr
--- | ---
dir = rtl, textDir = rtl | dir = rtl, textDir = ltr

# Test NumberSpinner Widget with _BidiSupport

Group 3
Try typing values, and use the up/down arrow keys and/or the arrow push buttons

dir = ltr, textDir = rtl | dir = ltr, textDir = ltr
--- | ---
dir = rtl, textDir = rtl | dir = rtl, textDir = ltr

# Test CurrencyTextBox Widget with _BidiSupport

Group 4

dir = ltr, textDir = rtl | dir = ltr, textDir = ltr
--- | ---
dir = rtl, textDir = rtl | dir = rtl, textDir = ltr

# Test TimeTextBox Widget with _BidiSupport

Group 5

dir = ltr, textDir = rtl | dir = ltr, textDir = ltr
--- | ---
dir = rtl, textDir = rtl | dir = rtl, textDir = ltr